Basic registration methods (sarpy.processing.registration.basic)
================================================================

.. automodule:: sarpy.processing.registration.basic
    :members:
    :show-inheritance:
    :inherited-members:
